@@ -224,7 +224,7 @@ def get_value_from_array(data_arr_input, low_li, up_li):
 def main():
     parser = argparse.ArgumentParser(prog='vinset',
                                      description='VINSET package.')
-    parser.add_argument('--version', action='version', version='2.0.3'),
+    parser.add_argument('--version', action='version', version='2.0.4'),
     parser.add_argument("-i", dest="input_filename", required=True, type=argparse.FileType('r'), default=sys.stdin,
                         help="input mp4 file", metavar="filename.mp4")
     parser.add_argument("-o", dest="output_filename", required=True, type=argparse.FileType('w'), default=sys.stdout,
@@ -501,53 +501,54 @@ def main():
                     parent_index = get_position_of_parent(search_str, axes_array)
                     axes_info = axes_array[parent_index]
                     if show_type == "pen" and parent_index is not None:
-                        ax_pos = axes_info["position"]
-                        ax_x = ax_pos["x"]
-                        ax_y = ax_pos["y"]
-                        ax_w = ax_pos["width"]
-                        ax_h = ax_pos["height"]
-                        zero_line_start_x = ax_x
-                        zero_line_y_scale = int(number_to_scale(lower_limit, upper_limit, ax_h, 0))
-                        zero_line_y = int(ax_y + ax_h - zero_line_y_scale)
-                        zero_line_end_x = ax_x + ax_w
-                        time_in_pixel_value = round((t_width / ax_w), 2)
-                        start_x = ax_x
-                        start_y = ax_y + int(ax_h / 2)
-                        # first_step = 0
-                        value_to_draw = False
+                        pass
+                        # ax_pos = axes_info["position"]
+                        # ax_x = ax_pos["x"]
+                        # ax_y = ax_pos["y"]
+                        # ax_w = ax_pos["width"]
+                        # ax_h = ax_pos["height"]
+                        # zero_line_start_x = ax_x
+                        # zero_line_y_scale = int(number_to_scale(lower_limit, upper_limit, ax_h, 0))
+                        # zero_line_y = int(ax_y + ax_h - zero_line_y_scale)
+                        # zero_line_end_x = ax_x + ax_w
+                        # time_in_pixel_value = round((t_width / ax_w), 2)
+                        # start_x = ax_x
+                        # start_y = ax_y + int(ax_h / 2)
+                        # # first_step = 0
+                        # value_to_draw = False
                         # step = 1
                         # end_x = 0
                         # end_y = 0
-                        len_array = len(display_arr)
-                        if len_array > 0:
-                            for ind, number in enumerate(display_arr):
-                                if zero_display:
-                                    cv2.line(clone_frame, (zero_line_start_x, zero_line_y),
-                                             (zero_line_end_x, zero_line_y),
-                                             line_color_array[i], zero_line_thick)
-                                if math.isnan(number[1]):
-                                    start_x = 0
-                                    start_y = 0
-                                    value_to_draw = False
-                                    pass
-                                else:
-                                    if not value_to_draw:
-                                        scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, number[1])
-                                        scaled_step = int(number[0] / time_in_pixel_value)
-                                        start_x = ax_x + scaled_step
-                                        start_y = int(ax_y + ax_h - scaled_num)
-                                        value_to_draw = True
-                                    else:
-                                        scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, number[1])
-                                        scaled_step = int(number[0] / time_in_pixel_value)
-                                        end_x = ax_x + scaled_step
-                                        end_y = int(ax_y + ax_h - scaled_num)
-                                        cv2.line(clone_frame, (start_x, start_y), (end_x, end_y),
-                                                 line_color_array[i], line_thickness, cv2.LINE_AA)
-                                        if need_to_draw_pointer and ind == len_array - 1:
-                                            cv2.circle(clone_frame, (end_x, end_y), pointer_radius, pointer_color, -1)
-                                        start_x = end_x
-                                        start_y = end_y
+                        # len_array = len(display_arr)
+                        # if len_array > 0:
+                        # for ind, number in enumerate(display_arr):
+                        #     if zero_display:
+                        #         cv2.line(clone_frame, (zero_line_start_x, zero_line_y),
+                        #                  (zero_line_end_x, zero_line_y),
+                        #                  line_color_array[i], zero_line_thick)
+                        #     if math.isnan(number[1]):
+                        #         start_x = 0
+                        #         start_y = 0
+                        #         value_to_draw = False
+                        #         pass
+                        #     else:
+                        #         if not value_to_draw:
+                        #             scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, number[1])
+                        #             scaled_step = int(number[0] / time_in_pixel_value)
+                        #             start_x = ax_x + scaled_step
+                        #             start_y = int(ax_y + ax_h - scaled_num)
+                        #             value_to_draw = True
+                        #         else:
+                        #             scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, number[1])
+                        #             scaled_step = int(number[0] / time_in_pixel_value)
+                        #             end_x = ax_x + scaled_step
+                        #             end_y = int(ax_y + ax_h - scaled_num)
+                        #             cv2.line(clone_frame, (start_x, start_y), (end_x, end_y),
+                        #                      line_color_array[i], line_thickness, cv2.LINE_AA)
+                        #             if need_to_draw_pointer and ind == len_array - 1:
+                        #                 cv2.circle(clone_frame, (end_x, end_y), pointer_radius, pointer_color, -1)
+                        #             start_x = end_x
+                        #             start_y = end_y
 
                     elif show_type == "refresh" and parent_index is not None:
                         ax_pos = axes_info["position"]
@@ -565,6 +566,7 @@ def main():
                         start_y = 0
                         value_to_draw = False
                         display_count = int(check_timer / (t_width * 1000))
+                        total_display_count = int(max_video_length / (t_width * 1000))
                         # end_x = 0
                         # end_y = 0
                         final_display_arr = display_arr[display_count][1]
@@ -591,7 +593,7 @@ def main():
                                     else:
                                         scaled_num = number_to_scale(lower_limit, upper_limit, ax_h, num[1])
                                         scaled_step = int(round(((num[0] / 1000) / time_in_pixel_value), 0))
-                                        if max_video_length > (t_width*1000) and ind == (len(final_display_arr) - 1):
+                                        if display_count != total_display_count and ind == (len(final_display_arr) - 1):
                                             end_x = ax_x + ax_w
                                         else:
                                             end_x = ax_x + scaled_step - (display_count * ax_w)
